@@ -2,7 +2,7 @@
  * vinagre-notebook.c
  * This file is part of vinagre
  *
- * Copyright (C) 2007 - Jonh Wendell <wendell@bani.com.br>
+ * Copyright (C) 2007,2008 - Jonh Wendell <wendell@bani.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -74,21 +74,6 @@ close_button_clicked_cb (GtkWidget *widget,
   vinagre_notebook_remove_tab (notebook, VINAGRE_TAB (tab));
 }
 
-static void
-tab_label_style_set_cb (GtkWidget *hbox,
-			GtkStyle *previous_style,
-			gpointer user_data)
-{
-  GtkWidget *button;
-  gint h, w;
-
-  gtk_icon_size_lookup_for_settings (gtk_widget_get_settings (hbox),
-				     GTK_ICON_SIZE_MENU, &w, &h);
-
-  button = g_object_get_data (G_OBJECT (hbox), "close-button");
-  gtk_widget_set_size_request (button, w + 2, h + 2);
-}
-
 static void
 tab_initialized_cb (VinagreTab *tab, VinagreNotebook *nb)
 {
@@ -109,7 +94,7 @@ tab_disconnected_cb (VinagreTab *tab, VinagreNotebook *nb)
 {
   gchar *message, *name;
 
-  name = vinagre_connection_best_name (vinagre_tab_get_conn (tab));
+  name = vinagre_connection_get_best_name (vinagre_tab_get_conn (tab));
   message = g_strdup_printf (_("Connection to host \"%s\" was closed."),
 			     name);
   vinagre_utils_show_error (message, GTK_WINDOW (nb->priv->window));
@@ -153,7 +138,10 @@ build_tab_label (VinagreNotebook *nb,
   rcstyle = gtk_rc_style_new ();
   rcstyle->xthickness = rcstyle->ythickness = 0;
   gtk_widget_modify_style (close_button, rcstyle);
-  gtk_rc_style_unref (rcstyle),
+  gtk_rc_style_unref (rcstyle);
+  gint w, h;
+  gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &w, &h);
+  gtk_widget_set_size_request (GTK_WIDGET (close_button), w+2, h+2);
 
   image = gtk_image_new_from_stock (GTK_STOCK_CLOSE,
 					  GTK_ICON_SIZE_MENU);
@@ -172,7 +160,7 @@ build_tab_label (VinagreNotebook *nb,
   gtk_box_pack_start (GTK_BOX (label_hbox), icon, FALSE, FALSE, 0);
 	
   /* setup label */
-  name = vinagre_connection_best_name (vinagre_tab_get_conn (tab));
+  name = vinagre_connection_get_best_name (vinagre_tab_get_conn (tab));
   label = gtk_label_new (name);
   g_free (name);
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
@@ -182,10 +170,6 @@ build_tab_label (VinagreNotebook *nb,
   dummy_label = gtk_label_new ("");
   gtk_box_pack_start (GTK_BOX (label_hbox), dummy_label, TRUE, TRUE, 0);
 	
-  /* Set minimal size */
-  g_signal_connect (hbox, "style-set",
-		    G_CALLBACK (tab_label_style_set_cb), NULL);
-	
   gtk_widget_show (hbox);
   gtk_widget_show (label_ebox);
   gtk_widget_show (label_hbox);
